package edu.uiuc.ncsa.security.delegation.server;


import edu.uiuc.ncsa.security.core.Identifier;
import edu.uiuc.ncsa.security.delegation.storage.impl.BasicTransaction;
import edu.uiuc.ncsa.security.delegation.token.AuthorizationGrant;

import java.net.URI;

/**
 * Server-side transactions. These should be stored between (the stateless) calls in the protocol.
 * <p>Created by Jeff Gaynor<br>
 * on Apr 16, 2010 at  10:36:51 AM
 */
public class ServiceTransaction extends BasicTransaction {
    public ServiceTransaction(Identifier identifier) {
        super(identifier);
    }

    public ServiceTransaction(AuthorizationGrant ag) {
        super(ag);
    }

    public boolean authGrantValid;
    public boolean accessTokenValid;

    public boolean isAuthGrantValid() {
        return authGrantValid;
    }

    public void setAuthGrantValid(boolean authGrantValid) {
        this.authGrantValid = authGrantValid;
    }


    public boolean isAccessTokenValid() {
        return accessTokenValid;
    }

    public void setAccessTokenValid(boolean accessTokenValid) {
        this.accessTokenValid = accessTokenValid;
    }

    public URI getCallback() {
        return callback;
    }

    public void setCallback(URI callback) {
        this.callback = callback;
    }

    URI callback;

     long lifetime = 0;

    public void setLifetime(long lifetime) {
        this.lifetime = lifetime;
    }

    /**
     * The lifetime of the certificate. This is stored internally in milliseconds, so must be
     * converted to seconds before use in most applications.
     * @return
     */
    public long getLifetime() {
        return lifetime;
    }
    public String toString() {
        String out = getClass().getSimpleName() + "[";
        out = out + "id=" + getIdentifierString() + ", authGrant=" + getAuthorizationGrant() + "(" + (isAuthGrantValid() ? "" : "in") + "valid)";
        out = out + ", verifier=" + (!hasVerifier() ? "(none)" : getVerifier());
        out = out + ", access token=" + getAccessToken() + "(" + (isAccessTokenValid() ? "" : "in") + "valid)";
        out = out + ", lifetime=" + getLifetime();
        return out + "]";
    }

    @Override
    public boolean equals(Object obj) {
        if (!super.equals(obj)) {
            return false;
        }
        if (!(obj instanceof ServiceTransaction)) {
            return false;
        }
        ServiceTransaction st = (ServiceTransaction) obj;
        if (isAuthGrantValid() != st.isAuthGrantValid()) return false;
        if (isAccessTokenValid() != st.isAccessTokenValid()) return false;
        if(getLifetime() != st.getLifetime()) return false;
        return true;
    }

}
